@@ -1,10 +1,16 @@
-__version__ = '7.7.0'
+__version__ = '7.8.0'
 
 
 _optional_dependencies = [
     {
         'name': 'CuPy',
         'packages': [
+            'cupy-cuda120',
+            'cupy-cuda114',
+            'cupy-cuda113',
+            'cupy-cuda112',
+            'cupy-cuda111',
+            'cupy-cuda110',
             'cupy-cuda102',
             'cupy-cuda101',
             'cupy-cuda100',
@@ -15,7 +21,7 @@ _optional_dependencies = [
             'cupy',
         ],
         'specifier': '>=7.7.0,<8.0.0',
-        'help': 'https://docs-cupy.chainer.org/en/latest/install.html',
+        'help': 'https://docs.cupy.dev/en/latest/install.html',
     },
     {
         'name': 'iDeep',
