@@ -51,6 +51,8 @@ import chainerx
 available = False  # type: bool
 cudnn_enabled = False  # type: bool
 
+_cupy_major = 0  # type: bool
+
 try:
     import cupy
     from cupy import cuda  # NOQA
@@ -66,7 +68,10 @@ try:
     from cupy.cuda import Stream  # type: ignore # NOQA
 
     # Alias for ignoring the warning in setup.cfg
-    from cupy.util import PerformanceWarning as _PerformanceWarning  # NOQA
+    try:
+        from cupy._util import PerformanceWarning as _PerformanceWarning  # NOQA
+    except ImportError:
+        from cupy.util import PerformanceWarning as _PerformanceWarning  # NOQA
 
     available = True
 except Exception as e:
@@ -116,8 +121,11 @@ except Exception as e:
 
 
 if available:
+    _cupy_major = numpy.lib.NumpyVersion(cupy.__version__).major
     _cudnn_disabled_by_user = int(os.environ.get('CHAINER_CUDNN', '1')) == 0
     try:
+        if 7 < _cupy_major:
+            import cupy.cuda.cudnn
         import cupy.cudnn
         cudnn = cupy.cudnn  # type: tp.Optional[types.ModuleType]
         libcudnn = cupy.cuda.cudnn  # type: tp.Any # NOQA
